@@ -1,7 +1,8 @@
 from wallace.config import ConfigError, setup_app
-from wallace.db import PostgresModel, PostgresTable
-from wallace.db import ExpiringRedisHash, RedisHash
-from wallace.db import Boolean, ByteArray, Float, Integer, Moment, Now, String
+from wallace.db import PostgresModel, PostgresPool, PostgresTable
+from wallace.db import ExpiringRedisHash, RedisHash, RedisSocket
+from wallace.db import Boolean, ByteArray, Float, Integer, Moment, Now
+from wallace.db import String, Unicode
 from wallace.db import DBError, DoesNotExist, ValidationError
 from wallace.errors import Error, WallaceError
 
@@ -11,11 +12,12 @@ __all__ = [
     'setup_app',
 
     # dbs / models
-    'PostgresModel', 'PostgresTable',
-    'ExpiringRedisHash', 'RedisHash',
+    'PostgresModel', 'PostgresPool', 'PostgresTable',
+    'ExpiringRedisHash', 'RedisHash', 'RedisSocket',
 
     # types
     'Boolean', 'ByteArray', 'Float', 'Integer', 'Moment', 'Now', 'String',
+    'Unicode',
 
     # errors
     'ConfigError', 'DBError', 'DoesNotExist', 'Error',
