@@ -1,9 +1,11 @@
+from wallace.config.cache import register_connection
 from wallace.config.errors import ConfigError
 from wallace.config.getters import GetApp, GetDBConn, GetParameter
 from wallace.config.ns import get_app, setup_app
 
 
 __all__ = [
+    'register_connection',
     'ConfigError',
     'GetApp', 'GetDBConn', 'GetParameter',
     'get_app', 'setup_app',
