@@ -1,16 +1,15 @@
 from wallace.db.base import Model, KeyValueModel, RelationalModel
 from wallace.db.base import DataType
 from wallace.db.base import Boolean, ByteArray, DataType, Float, Integer
-from wallace.db.base import Moment, Now, String
+from wallace.db.base import Moment, Now, String, Unicode
 from wallace.db.base import DBError, DoesNotExist, ValidationError
 from wallace.db.pg import PostgresModel, PostgresPool, PostgresTable
-from wallace.db.redisdb import RedisHash, ExpiringRedisHash
+from wallace.db.redisdb import ExpiringRedisHash, RedisHash, RedisSocket
 
 
 __all__ = [
     # base
-    'Model', 'KeyValueModel', 'RelationalModel',
-    'DataType',
+    'DataType', 'KeyValueModel', 'Model', 'RelationalModel',
 
     # errors
     'DBError', 'DoesNotExist', 'ValidationError',
@@ -19,9 +18,9 @@ __all__ = [
     'PostgresModel', 'PostgresPool', 'PostgresTable',
 
     # redis
-    'ExpiringRedisHash', 'RedisHash',
+    'ExpiringRedisHash', 'RedisHash', 'RedisSocket',
 
     # types
     'Boolean', 'ByteArray', 'DataType', 'Float', 'Integer', 'Moment', 'Now',
-    'String',
+    'String', 'Unicode',
 ]
