@@ -1,6 +1,6 @@
 from wallace.db.base.attrs import DataType
 from wallace.db.base.attrs import Boolean, ByteArray, Float, Integer, Moment
-from wallace.db.base.attrs import Now, String
+from wallace.db.base.attrs import Now, String, Unicode
 from wallace.db.base.errors import DBError, DoesNotExist, ValidationError
 from wallace.db.base.model import Model
 from wallace.db.base.keyval import KeyValueModel
@@ -9,11 +9,11 @@ from wallace.db.base.relational import RelationalModel
 
 __all__ = [
     # models
-    'Model', 'KeyValueModel', 'RelationalModel',
+    'KeyValueModel', 'Model', 'RelationalModel',
 
     # types
     'Boolean', 'ByteArray', 'DataType', 'Float', 'Integer', 'Moment', 'Now',
-    'String',
+    'String', 'Unicode',
 
     # errors
     'DBError', 'DoesNotExist', 'ValidationError',
